@@ -17,7 +17,7 @@ class PluginDetails(object):
             if task.no_entries_ok:
                 log.verbose('Task didn\'t produce any entries.')
             else:
-                log.verbose('Task didn\'t produce any entries. This is likely due to a mis-configured or non-functional input.')
+                log.warning('Task didn\'t produce any entries. This is likely due to a mis-configured or non-functional input.')
         else:
             log.verbose('Produced %s entries.' % (len(task.entries)))
 
